@@ -100,7 +100,7 @@ const VTKStreamlit: React.FunctionComponent = () => {
     }
   }, [renderData])
   
-  const loadFile = useCallback((file: Uint8Array) => {
+  const loadFile = (file: Uint8Array) => {
     if (viewerRef.current && viewerRef.current.dispatch && viewerRef.current.loadFile) {
 
       if(renderData && renderData.args["clear"]) viewerRef.current.dispatch({ type: 'remove-all' }, true)
@@ -111,7 +111,7 @@ const VTKStreamlit: React.FunctionComponent = () => {
       const config = scene.length > 0 ? scene : undefined
       viewerRef.current.loadFile(new Blob([file]), 'vtkjs', config)
     }
-  }, [renderData])
+  }
 
   useEffect(() => {
     if (!file) return
@@ -131,17 +131,16 @@ const VTKStreamlit: React.FunctionComponent = () => {
 
   // initial state of streamlit component
   useEffect(() => {
-    // Streamlit.setComponentValue({})
     Streamlit.setFrameHeight(HEIGHT)
   }, [])
 
   const cssStyle = useMemo(() => {
     return renderData && typeof renderData.args["style"] !== 'undefined' ? 
       renderData.args["style"] : 
-      { border: "1px solid #d0d7de", borderRadius: "2px" }
+      { border: "1px solid #d0d7de", borderRadius: "2px", height: `${HEIGHT}px` }
   }, [renderData])
 
-  if (renderData == null) {
+  if (!viewerRef.current) {
     return (
       <div style={{
         height: `${HEIGHT}px`,
